import os
import pytest
import numpy as np

import mdevaluate as md
import store.eval as seval
import store.analyse as sana


@pytest.fixture
def water_trajectory(request, scope='module'):
    dname = os.environ.get('STORE_TESTDATA', '/autohome/niels/Projects/mdevaluate/test/data/water')
    return md.open(dname)


def test_oaf(water_trajectory):
    kwargs = {'segments': 10, 'window': 0.5}
    dipole = sana.water_dipole(water_trajectory)
    res_1 = sana.oaf(dipole, order=1, **kwargs)['F1'].cor.values
    res_2 = sana.oaf(dipole, order=2, **kwargs)['F2'].cor.values
    assert (res_2 <= res_1).all()

    bonds = sana.water_OH_bonds(water_trajectory)
    res_1 = sana.oaf(bonds, order=1, **kwargs)['F1'].cor.values
    res_2 = sana.oaf(bonds, order=2, **kwargs)['F2'].cor.values
    assert (res_2 <= res_1).all()
